@@ -10,6 +10,18 @@ class IWorkers(ABC):
     according to the available CPU and memory resources of the current machine.
     """
 
+    @abstractmethod
+    def setRamPerWorker(self, ram_per_worker: float) -> None:
+        """
+        Set the amount of RAM allocated per worker.
+
+        Parameters
+        ----------
+        ram_per_worker : float
+            Amount of RAM (in GB) allocated per worker.
+        """
+        pass
+
     @abstractmethod
     def calculate(self) -> int:
         """
